@@ -45,7 +45,7 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
                     beta       = beta2,
                     parindx    = object$parindx,
                     link       = object$link,
-                    fixed      = object$fixed,
+                    fixedpar   = object$fixed,
                     designD    = D.designmatrix,
                     design     = object$design,
                     design0    = object$design0,
@@ -73,7 +73,7 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
                 beta       = .localstuff$beta,
                 parindx    = object$parindx,
                 link       = object$link,
-                fixed      = object$fixed,
+                fixedpar   = object$fixed,
                 designD    = D.designmatrix,
                 design     = object$design,
                 design0    = object$design0,
@@ -103,7 +103,7 @@ confint.secr <- function (object, parm, level = 0.95, newdata = NULL,
             fit <- secr.fit (capthist = object$capthist, mask = object$mask,
                 buffer = object$buffer, CL = object$CL, detectfn = object$detectfn,
                 start = object$fit$par, binomN= details$binomN,
-                link = object$link, fixed = object$fixed,  model = object$model,
+                link = object$link, fixedpar = object$fixed,  model = object$model,
                 timecov = object$timecov, sessioncov = object$sessioncov,
                 groups = object$groups, dframe = object$dframe,
                 details = details, verify = FALSE, ...)$fit
