@@ -263,13 +263,14 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
         mask <- mask[[sessnum]]
     beta <- object$fit$par
 
-    traps   <- attr(capthists, 'traps')  ## need session-specific traps
-    if (!(detector(traps) %in% .localstuff$individualdetectors))
-        stop ("require individual detector type for sumDpdot")
-    dettype <- detectorcode(traps)
     n       <- max(nrow(capthists), 1)
     s       <- ncol(capthists)
     noccasions <- s
+    trps   <- traps(capthists)  ## need session-specific traps
+    if (!(detector(trps) %in% .localstuff$individualdetectors))
+        stop ("require individual detector type for sumDpdot")
+
+    dettype <- detectorcode(trps)
     nmix    <- object$details$nmix
     nmix    <- ifelse (is.null(nmix), 1, nmix)
 
@@ -282,17 +283,20 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
     ##############################################
 
     if (dettype %in% c(3,6)) {
-        k <- c(table(polyID(traps)),0)
+        k <- c(table(polyID(trps)),0)
         K <- length(k)-1
     }
     else if (dettype %in% c(4,7)) {
-        k <- c(table(transectID(traps)),0)
+        k <- c(table(transectID(trps)),0)
         K <- length(k)-1
     }
     else {
-        k <- nrow(traps)
+        k <- nrow(trps)
         K <- k
     }
+
+    binomN <- object$details$binomN
+
     m      <- length(mask$x)            ## need session-specific mask...
     if (constant) {
         if (is.null(beta))
@@ -303,7 +307,7 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
             real <- as.list(real)
             names(real) <- parnames(object$detectfn)
         }
-        a <- cellarea * sum(pdot(X = mask, traps = traps, detectfn = object$detectfn,
+        a <- cellarea * sum(pdot(X = mask, traps = trps, detectfn = object$detectfn,
                              detectpar = real, noccasions = noccasions))
         return(a * D)
     }
@@ -330,7 +334,14 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
         Xrealparval0 <- scaled.detection (realparval0, FALSE,
             object$details$scaleg0, NA)
 
-        used <- usage(traps)
+        usge <- usage(trps)
+        if (is.null(usge)) {
+            usge <- matrix(1, nrow = K, ncol = s)
+            used <- 1
+        }
+        else {
+            used <- (usge > 1e-10) * 1
+        }
         if (any(used==0))
         PIA <- PIA * rep(rep(t(used),rep(n,s*K)),nmix)
         ncolPIA <- n
@@ -351,16 +362,40 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
             mask <- cbind (mask, D)
             useD <- TRUE
         }
+
+#        print(dettype)
+#        print(param)
+#        print(Xrealparval0)
+#        print(n)
+#        print(s)
+#        print(k)
+#        print(m)
+#        print(nmix)
+#        print(summary(trps))
+#        print(usge)
+#        print(summary(mask))
+#        print(nrow(Xrealparval0))
+#        print(PIA)
+#        print(ncolPIA)
+#        print(cellarea)
+#        print(miscparm)
+#        print(object$detectfn)
+#        print(object$details$binomN)
+#        print(useD)
+
         temp <- .C("integralprw1", PACKAGE = 'secr',
             as.integer(dettype),
             as.integer(param),
             as.double(Xrealparval0),
+            as.integer(rep(1,n)),    # dummy groups 2012-11-13
             as.integer(n),
             as.integer(s),
             as.integer(k),
             as.integer(m),
+            as.integer(1),          # dummy ngroups 2012-11-13
             as.integer(nmix),
-            as.double(unlist(traps)),
+            as.double(unlist(trps)),
+            as.double(usge),
             as.double(as.numeric(unlist(mask))),
             as.integer(nrow(Xrealparval0)), # rows in lookup
             as.integer(PIA),                # index of nc*,S,K to rows in realparval0
@@ -368,19 +403,22 @@ sumDpdot <- function (object, sessnum = 1, mask, D, cellarea, constant = TRUE,
             as.double(cellarea),
             as.double(miscparm),
             as.integer(object$detectfn),
-            as.integer(object$details$binomN),
+            as.integer(binomN),
             as.integer(useD),
-            a=double(n),
-            resultcode=integer(1)
+            a = double(n),
+            resultcode = integer(1)
        )
-       if (temp$resultcode == 3)
-           stop ("groups not implemented in external function 'integralprw1'")
+                                        # 2012-11-13
+#       if (temp$resultcode == 3)
+#           stop ("groups not implemented in external function 'integralprw1'")
        if (temp$resultcode != 0)
            stop ("error in external function 'integralprw1'")
+
        ## constant density case, D not passed to integralprw1
        if (length(D) == 1) {
            temp$a <- temp$a * D
        }
+
        if (oneminus) {
            sumD <- ifelse (length(D) == 1, D * nrow(mask), sum(D))
            return(sumD * cellarea - temp$a)
